aboutsummaryrefslogtreecommitdiffstats
path: root/src/OutputInternal.hxx
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2013-10-28 10:12:21 +0100
committerMax Kellermann <max@duempel.org>2013-10-28 10:12:33 +0100
commit5b5675cc121eff6ba4b89719a523bfbe3993ce2f (patch)
tree92bd72d3f460d184d5769256270c76db0fb6080b /src/OutputInternal.hxx
parente699f6781e144d02336856d460a74fbaf988447d (diff)
downloadmpd-5b5675cc121eff6ba4b89719a523bfbe3993ce2f.tar.gz
mpd-5b5675cc121eff6ba4b89719a523bfbe3993ce2f.tar.xz
mpd-5b5675cc121eff6ba4b89719a523bfbe3993ce2f.zip
player_control: rename to PlayerControl
Diffstat (limited to 'src/OutputInternal.hxx')
-rw-r--r--src/OutputInternal.hxx7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/OutputInternal.hxx b/src/OutputInternal.hxx
index a6233c5b5..2b3136f94 100644
--- a/src/OutputInternal.hxx
+++ b/src/OutputInternal.hxx
@@ -32,6 +32,7 @@ class Error;
class Filter;
class MusicPipe;
struct config_param;
+struct PlayerControl;
typedef struct _GTimer GTimer;
enum audio_output_command {
@@ -225,10 +226,10 @@ struct audio_output {
Cond cond;
/**
* The player_control object which "owns" this output. This
* object is needed to signal command completion.
*/
- struct player_control *player_control;
+ PlayerControl *player_control;
/**
* The #music_chunk which is currently being played. All
@@ -264,7 +265,7 @@ audio_output_command_is_finished(const struct audio_output *ao)
struct audio_output *
audio_output_new(const config_param &param,
- player_control &pc,
+ PlayerControl &pc,
Error &error);
bool
@@ -225,10 +226,10 @@ struct audio_output {
Cond cond;
/**
- * The player_control object which "owns" this output. This
+ * The PlayerControl object which "owns" this output. This
* object is needed to signal command completion.
*/